%define selinux_variants mls strict targeted

Name:		arm4
Version:	0.8.2
Release:	2%{?dist}
Summary:	Application Response Measurement V4.0

Group:		Development/System
License:	EPL
URL:		http://www.arm4.org/
Source0:	http://downloads.sourceforge.net/arm4/arm4-0.8.2.tar.gz
Source2:	arm4-README.fedora
Source3:	arm4-arm4.cron
Source4:	arm4-arm4.init
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:	e2fsprogs-devel openssl-devel db4-utils db4-devel libxml2-devel sqlite-devel xerces-c-devel ant ant-javadoc
Requires:	openssl db4 db4-cxx sqlite
Requires(pre): shadow-utils	

%description
An Open Source implementation of the Open Group's
Application Response Measurement (ARM) standard
version 4.0. The ARM agent allows you to measure
response times for related transactions across
multiple tiers in a distributed environment.

%package devel
Summary: Files needed to build applications using ARM
Requires: %{name} = %{version}-%{release}

Group: Development/Libraries

%description devel
Files needed to build programs using the Application Response Measurement
(ARM) V4.0 standard.

%package java
Summary: Java language bindings for applications using ARM
Requires: %{name} = %{version}-%{release}

Group: Development/Libraries

%description java
Files needed to build java language programs using the Application Response
Measurement (ARM) V4.0 standard.

#
# Location of agent databases
%define contentdir %{_localstatedir}/lib/arm4
%define rundir %{_localstatedir}/run/arm4

%prep
%setup -q -n arm4-%{version}
cp -a %{SOURCE2} README.fedora

%build
%configure --disable-static --enable-sqlite --disable-examples --disable-tests --with-jdkhome=/etc/alternatives/java_sdk
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}

# These aren't really required in the final system
rm -rf %{buildroot}%{_datadir}/aclocal

#
# Move the java documentation
mv %{buildroot}%{_datadir}/doc/%{name}-%{version} \
	%{buildroot}%{_datadir}/doc/%{name}-java-%{version}

#
# Remove development versions of libraries that aren't intended for development
rm %{buildroot}%{_libdir}/libarm4db.so
rm %{buildroot}%{_libdir}/libarm4db_bdb.so
rm %{buildroot}%{_libdir}/libarm4db_sqlite.so
rm %{buildroot}%{_libdir}/libarm4db_common.so
rm %{buildroot}%{_libdir}/libArmNative.so

#
# Remove any libtool archives
rm %{buildroot}%{_libdir}/*.la

# Make our configuration dir if it doesn't exist
mkdir -p %{buildroot}%{_sysconfdir}/rc.d/init.d
install -m 644 -p %{_builddir}/%{name}-%{version}/config/arm4.conf %{buildroot}%{_sysconfdir}
install -m 755 -p %{SOURCE4} %{buildroot}%{_sysconfdir}/rc.d/init.d/arm4
mkdir -p %{buildroot}%{contentdir}
mkdir -p %{buildroot}%{rundir}

# Install a cron job to archive and age data
mkdir -p %{buildroot}%{_sysconfdir}/cron.daily
install -m 755 -p %{SOURCE3} %{buildroot}%{_sysconfdir}/cron.daily/arm4.cron

%pre
# Add the arm4 user and group
getent group arm4 >/dev/null || groupadd -r arm4
getent passwd arm4 >/dev/null || \
	useradd -r -g arm4 -d %{contentdir} -s /sbin/nologin \
	-c "ARM 4 Daemon" arm4
exit 0

%post
/sbin/ldconfig

# Register the arm4 service
/sbin/chkconfig --add arm4

%post devel -p /sbin/ldconfig

%post java -p /sbin/ldconfig

%preun
if [ $1 = 0 ]; then
	/sbin/service arm4 stop > /dev/null 2>&1
	/usr/bin/arm4_control remove > /dev/null 2>&1
	/sbin/chkconfig --del arm4
fi

%postun -p /sbin/ldconfig

%postun devel -p /sbin/ldconfig

%postun java -p /sbin/ldconfig

%clean
rm -rf %{buildroot}


%files
%defattr(-,root,root,-)
%doc README README.fedora COPYING
%{_bindir}/arm4_control
%{_bindir}/arm4_daemon
%{_bindir}/arm4_dump
%{_bindir}/arm4_export
%{_bindir}/arm4_report
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_libdir}/libarm4db.*
%{_libdir}/libarm4db_bdb.*
%{_libdir}/libarm4db_sqlite.*
%{_libdir}/libarm4db_common.*
# The .so file is included here and not in the -devel package
# as many applications link against these libraries dynamically,
# and it is required by the standard
%{_libdir}/libarm4.so*
%{_libdir}/libarm4_null.so*
%config(noreplace) %{_sysconfdir}/arm4.conf
%{_sysconfdir}/rc.d/init.d/arm4
%{_sysconfdir}/cron.daily/arm4.cron
%attr(755,arm4,arm4) %dir %{contentdir}
#%attr(755,arm4,arm4) %dir %{contentdir}/data
#%attr(1777,arm4,arm4) %dir %{contentdir}/queue
%attr(755,arm4,arm4) %dir %{rundir}
%{_datadir}/%{name}-%{version}/arm4db.xsd

%files devel
%defattr(-,root,root,-)
%{_includedir}/*
%{_mandir}/man3/*

%files java
%defattr(-,root,root,-)
%{_datadir}/doc/%{name}-java-%{version}/apidocs
%{_libdir}/arm4*
%{_libdir}/libArmNative.*

%changelog
* Sat Aug 8 2009 David Carter <dcarter@entertain-me.com> - 0.8.2-2
- Changed incorrect dependency from uuid-devel to e2fsprogs-devel

* Sun May 3 2009 David Carter <dcarter@entertain-me.com> - 0.8.2-1
- Improved stability and performance
- Assorted bug fixes

* Fri Apr 3 2009 David Carter <dcarter@entertain-me.com> - 0.8.1-0.7
- Missing jni.h caused build issues with F-11 F-12

* Sun Nov 30 2008 David Carter <dcarter@entertain-me.com> - 0.8.1-0.6
- Updated to latest release, which removed arm4sdk and all references
- Removed static library versions
- arm4-tests removed until new tests can be added that don't depend on the SDK

* Sat Nov 1 2008 David Carter <dcarter@entertain-me.com> - 0.8-0.5
- Removed assertions that caused early exit from libraries

* Mon Oct 27 2008 David Carter <dcarter@entertain-me.com> - 0.8-0.4
- Update to latest release version
- Includes more documentation and many bug fixes. SE Linux support is
  removed as it's not yet complete.

* Thu Oct 2 2008 David Carter <dcarter@entertain-me.com> - 0.8-0.3.final
- Update to latest beta version
- Includes more documentation and many bug fixes, selinux rules

* Mon Sep 4 2008 David Carter <dcarter@entertain-me.com> - 0.8-0.2.beta3
- Update to latest beta version
- Includes more documentation and many bug fixes

* Sun Aug 3 2008 David Carter <dcarter@entertain-me.com> - 0.8-0.1.beta2
- Initial packaging as RPM
